Skip to content
Closed
Show file tree
Hide file tree
Changes from all commits
Commits
Show all changes
28 commits
Select commit Hold shift + click to select a range
41844f2
Cit -m RAII guards for memory allocations and streams, define some co…
music-dino Sep 30, 2022
858da0e
Implement helper function for generating allocation flags
music-dino Oct 3, 2022
4214882
EXSWHTEC-75 - Implement tests for hipMemcpyAsync and derivatives
music-dino Oct 3, 2022
e534d2e
EXSWHTEC-94 - Implement helper classes and functions for memory tests
music-dino Oct 6, 2022
09ce86a
EXSWHTEC-94 - Remove c++14 standard constraint on memory tests
music-dino Oct 6, 2022
fc03930
Merge branch 'utils' into hipMemcpyAsync_tests
music-dino Oct 6, 2022
48b337f
EXSWHTEC-94 - Remove GenerateLinearAllocationFlagCombinations until f…
music-dino Oct 6, 2022
2d3b7a7
Merge branch 'develop' into utils
music-dino Oct 8, 2022
715cf30
EXSWHTEC-94 - Implement helper classes and functions for memory tests
music-dino Oct 6, 2022
a74fe21
EXSWHTEC-94 - Remove c++14 standard constraint on memory tests
music-dino Oct 6, 2022
350958e
EXSWHTEC-94 - Remove GenerateLinearAllocationFlagCombinations until f…
music-dino Oct 6, 2022
ea6689c
Merge branch 'develop' into utils
music-dino Oct 10, 2022
2a44046
Merge remote-tracking branch 'origin/utils' into utils
mirza-halilcevic Oct 10, 2022
691d00e
EXSWHTEC-94 - Implement helper classes and functions for memory tests
music-dino Oct 6, 2022
7bdf52f
EXSWHTEC-94 - Remove c++14 standard constraint on memory tests
music-dino Oct 6, 2022
1185c39
EXSWHTEC-94 - Remove GenerateLinearAllocationFlagCombinations until f…
music-dino Oct 6, 2022
8d2e833
Merge remote-tracking branch 'origin/utils' into utils
music-dino Oct 11, 2022
e003c4f
Merge remote-tracking branch 'origin/utils' into utils
mirza-halilcevic Oct 12, 2022
8911eb7
EXSWHTEC-94 - Implement resource guards for hipMallocPitch and 3D
mirza-halilcevic Oct 12, 2022
7b7a03d
Merge remote-tracking branch 'origin/utils' into hipMemcpyAsync_tests
music-dino Oct 14, 2022
e1e1209
EXSWHTEC-75 - Update invalid stream negative tests and bring in line …
music-dino Oct 14, 2022
b1a68bd
Merge remote-tracking branch 'origin/utils' into utils
music-dino Oct 14, 2022
76c8e31
EXSWHTEC-94 - Add resource guards for 2D and 3D allocations and utils…
music-dino Oct 14, 2022
35f373e
Merge remote-tracking branch 'upstream/develop' into utils
music-dino Oct 14, 2022
1f71528
Merge remote-tracking branch 'upstream/develop' into utils
music-dino Oct 17, 2022
c889b48
Merge remote-tracking branch 'upstream/develop' into utils
music-dino Oct 17, 2022
c9e92e0
Merge branch 'utils' into hipMemcpyAsync_tests
music-dino Oct 18, 2022
6c2511e
Merge remote-tracking branch 'origin/hipMemcpyAsync_tests' into hipMe…
music-dino Oct 18, 2022
File filter

Filter by extension

Filter by extension

Conversations
Failed to load comments.
Loading
Jump to
Jump to file
Failed to load files.
Loading
Diff view
Diff view
61 changes: 57 additions & 4 deletions tests/catch/include/resource_guards.hh
Original file line number Diff line number Diff line change
Expand Up @@ -80,17 +80,70 @@ template <typename T> class LinearAllocGuard {
}
}

T* ptr() { return ptr_; };
T* const ptr() const { return ptr_; };
T* host_ptr() { return host_ptr_; }
T* const host_ptr() const { return host_ptr(); }
T* ptr() const { return ptr_; };
T* host_ptr() const { return host_ptr_; }

private:
const LinearAllocs allocation_type_;
T* ptr_ = nullptr;
T* host_ptr_ = nullptr;
};

template <typename T> class LinearAllocGuardMultiDim {
protected:
LinearAllocGuardMultiDim(hipExtent extent) : extent_{extent} {}

~LinearAllocGuardMultiDim() { static_cast<void>(hipFree(pitched_ptr_.ptr)); }

public:
T* ptr() const { return reinterpret_cast<T*>(pitched_ptr_.ptr); };

size_t pitch() const { return pitched_ptr_.pitch; }

hipExtent extent() const { return extent_; }

hipPitchedPtr pitched_ptr() const { return pitched_ptr_; }

size_t width() const { return extent_.width; }

size_t width_logical() const { return extent_.width / sizeof(T); }

size_t height() const { return extent_.height; }

public:
hipPitchedPtr pitched_ptr_;
const hipExtent extent_;
};

template <typename T> class LinearAllocGuard2D : public LinearAllocGuardMultiDim<T> {
public:
LinearAllocGuard2D(const size_t width_logical, const size_t height)
: LinearAllocGuardMultiDim<T>{make_hipExtent(width_logical * sizeof(T), height, 1)} {
HIP_CHECK(hipMallocPitch(&this->pitched_ptr_.ptr, &this->pitched_ptr_.pitch,
this->extent_.width, this->extent_.height));
}

LinearAllocGuard2D(const LinearAllocGuard2D&) = delete;
LinearAllocGuard2D(LinearAllocGuard2D&&) = delete;
};

template <typename T> class LinearAllocGuard3D : public LinearAllocGuardMultiDim<T> {
public:
LinearAllocGuard3D(const size_t width_logical, const size_t height, const size_t depth)
: LinearAllocGuardMultiDim<T>{make_hipExtent(width_logical * sizeof(T), height, depth)} {
HIP_CHECK(hipMalloc3D(&this->pitched_ptr_, this->extent_));
}

LinearAllocGuard3D(const hipExtent extent) : LinearAllocGuardMultiDim<T>(extent) {
HIP_CHECK(hipMalloc3D(&this->pitched_ptr_, this->extent_));
}

LinearAllocGuard3D(const LinearAllocGuard3D&) = delete;
LinearAllocGuard3D(LinearAllocGuard3D&&) = delete;

size_t depth() const { return this->extent_.depth; }
};

enum class Streams { nullstream, perThread, created };

class StreamGuard {
Expand Down
43 changes: 43 additions & 0 deletions tests/catch/include/utils.hh
Original file line number Diff line number Diff line change
Expand Up @@ -54,6 +54,37 @@ void ArrayFindIfNot(T* const array, const T expected_value, const size_t num_ele
ArrayFindIfNot(array, array + num_elements, expected_value);
}

template <typename T, typename F>
void PitchedMemoryVerify(T* const ptr, const size_t pitch, const size_t width, const size_t height,
const size_t depth, F expected_value_generator) {
for (int z = 0; z < depth; ++z) {
for (int y = 0; y < height; ++y) {
for (int x = 0; x < width; ++x) {
const auto slice = reinterpret_cast<uint8_t*>(ptr) + pitch * height * z;
const auto row = slice + pitch * y;
if (reinterpret_cast<T*>(row)[x] != expected_value_generator(x, y, z)) {
INFO("Mismatch at indices: " << x << ", " << y << ", " << z);
REQUIRE(reinterpret_cast<T*>(row)[x] == expected_value_generator(x, y, z));
}
}
}
}
}

template <typename T, typename F>
void PitchedMemorySet(T* const ptr, const size_t pitch, const size_t width, const size_t height,
const size_t depth, F expected_value_generator) {
for (int z = 0; z < depth; ++z) {
for (int y = 0; y < height; ++y) {
for (int x = 0; x < width; ++x) {
const auto slice = reinterpret_cast<uint8_t*>(ptr) + pitch * height * z;
const auto row = slice + pitch * y;
reinterpret_cast<T*>(row)[x] = expected_value_generator(x, y, z);
}
}
}
}

template <typename T>
__global__ void VectorIncrement(T* const vec, const T increment_value, size_t N) {
size_t offset = (blockIdx.x * blockDim.x + threadIdx.x);
Expand Down Expand Up @@ -82,6 +113,18 @@ static __global__ void Delay(uint32_t interval, const uint32_t ticks_per_ms) {
}
}

template <typename T>
__global__ void Iota(T* const out, size_t pitch, size_t w, size_t h, size_t d) {
const auto x = blockIdx.x * blockDim.x + threadIdx.x;
const auto y = blockIdx.y * blockDim.y + threadIdx.y;
const auto z = blockIdx.z * blockDim.z + threadIdx.z;
if (x < w && y < h && z < d) {
char* const slice = reinterpret_cast<char*>(out) + pitch * h * z;
char* const row = slice + pitch * y;
reinterpret_cast<T*>(row)[x] = z * w * h + y * w + x;
}
}

inline void LaunchDelayKernel(const std::chrono::milliseconds interval, const hipStream_t stream) {
int ticks_per_ms = 0;
// Clock rate is in kHz => number of clock ticks in a millisecond
Expand Down
4 changes: 4 additions & 0 deletions tests/catch/unit/memory/CMakeLists.txt
Original file line number Diff line number Diff line change
Expand Up @@ -76,6 +76,8 @@ set(TEST_SRC
hipHostMalloc.cc
hipMemcpy.cc
hipMemcpyAsync.cc
hipMemcpyAsync_derivatives.cc
hipMemcpyAsync_old.cc
hipMemsetFunctional.cc
hipMallocPitch.cc
hipMallocArray.cc
Expand Down Expand Up @@ -152,6 +154,8 @@ set(TEST_SRC
hipHostMalloc.cc
hipMemcpy.cc
hipMemcpyAsync.cc
hipMemcpyAsync_derivatives.cc
hipMemcpyAsync_old.cc
hipMemsetFunctional.cc
hipMallocPitch.cc
hipMallocArray.cc
Expand Down
Loading